==> yaunc-1.00.tar.gz: yaunc-1.00/main.c <==
/* Yet Another Uptimes.Net Client - yaunc.c */

#include <stdio.h>
#include <stdlib.h>
#include <setjmp.h>
#include <signal.h>
#include <unistd.h>
#include <assert.h>

#include "yaunc.h"


/* Main */
int 
main (int argc, char *argv[])
{
	char send_me[MAXLINE];
	float idle;                     /* total idle time */
	float load;			/* really, percent non-idle */
	int error_test;
	struct utsname system_info;           /* uname() info in here */
	time_t uptime;                        /* system's uptime */
   	extern sigjmp_buf jumpbuffer;          /* for setjmp/longjmp */
	int option;
	const char * client = "Yaunc 1.0/UP5";

   	/* some simple initializations */
   	SetConfFilePath(DEFAULT_CONF_PATH);
	SetAlreadyDaemon(0);

	/* parse the command line options */
	while ( (option = getopt(argc, argv, OPTION_STRING)) != EOF) {	
		#ifdef DEBUG1
		printf("argc: %d option: %c\n", argc, option);
		#endif

		switch(option) {
			case 'f' :
				SetConfFilePath(optarg);
				#ifdef DEBUG1
					fprintf(stderr, "conf file arg: %s\n", GetConfFilePath());
				#endif
				break;
			case 'h' : case '?' : default :
				usage();
				break;     /* we shouldn't get here */
		}
	}	

   /* set signal handlers */
	if (signal(SIGHUP, sig_hup) == SIG_ERR)
	   err_log_sys("%s: SIGHUP catcher failure", NAME);

	/* return here on SIGHUP and clear these values */	
	if (sigsetjmp(jumpbuffer, 1) == 1) {
		free(GetAuth());
	}	

	/* read the conf file */
	if ( read_conf() == -1 ) {
		err_sys("%s: read_conf() failed", NAME);
	}	

   /* make sure they've setup the conf file properly */
	if ( (strcmp(GetAuth(), "setme") == 0) ) {
	   err_sys("Configuration file still has default values, edit %s and rerun yaunc.", GetConfFilePath());
	}	
		  
	/* if we're set to be a daemon, detach and do all that fun stuff */
	if ((GetDaemonFlag() != 0) && (GetAlreadyDaemon() == 0)) {
		if ( daemon_init() == -1)
			err_sys("daemon_init() failure, exitting");
		
		/* report process starting on syslog */
		err_log_msg("Starting in daemon mode");
		SetAlreadyDaemon(1);
	}

	/* get system information (type, etc) */
	if ( (error_test = uname(&system_info)) == -1) {
		err_log_msg("uname() failed, continuing");
	}
	
	/* main processing loop */
	do {
		if ( (uptime = get_uptime(&idle)) == -1)
		   err_log_sys("get_uptime() failed, exitting");

		snprintf(send_me, MAXLINE, "%s|%d|%1.2f|%1.2f|%s|%s|%s|%s",
			GetAuth(), (int) uptime, load, idle, 
			system_info.sysname, system_info.release, system_info.machine, 
			client);
		   
	#ifdef DEBUG1
		fprintf(stderr, "not sent yet:\n%s\n", send_me);
	#endif

	#ifndef DEBUG1
		/* make the data string and send it along it's merry way */
		if (send_data(send_me) < 0)
			err_log_ret("%s: send_data() failed, continuing", NAME);
	#endif
	} while ((sleep(GetDelay()) == 0));

	/* never reached */
	exit(0);
}

==> yaunc-1.02.tar.gz: yaunc-1.02/main.c <==
/* Yet Another Uptimes.Net Client - yaunc.c */

#include <stdio.h>
#include <stdlib.h>
#include <setjmp.h>
#include <signal.h>
#include <unistd.h>
#include <assert.h>

#include "yaunc.h"


/* Main */
int 
main (int argc, char *argv[])
{
	char send_me[MAXLINE];
	float idle;                     /* total idle time */
	float load;			/* really, percent non-idle */
	int error_test;
	struct utsname system_info;           /* uname() info in here */
	time_t uptime;                        /* system's uptime */
   	extern sigjmp_buf jumpbuffer;          /* for setjmp/longjmp */
	int option;
	const char * client = "Yaunc 1.0/UP5";

   	/* some simple initializations */
   	SetConfFilePath(DEFAULT_CONF_PATH);
	SetAlreadyDaemon(0);

	/* parse the command line options */
	while ( (option = getopt(argc, argv, OPTION_STRING)) != EOF) {	
		#ifdef DEBUG1
		printf("argc: %d option: %c\n", argc, option);
		#endif

		switch(option) {
			case 'f' :
				SetConfFilePath(optarg);
				#ifdef DEBUG1
					fprintf(stderr, "conf file arg: %s\n", GetConfFilePath());
				#endif
				break;
			case 'h' : case '?' : default :
				usage();
				break;     /* we shouldn't get here */
		}
	}	

   /* set signal handlers */
	if (signal(SIGHUP, sig_hup) == SIG_ERR)
	   err_sys("%s: SIGHUP catcher failure", NAME);

	/* return here on SIGHUP and clear these values */	
	if (sigsetjmp(jumpbuffer, 1) == 1) {
		free(GetAuth());
	}	

	/* read the conf file */
	if ( read_conf() == -1 ) {
		err_sys("%s: read_conf() failed", NAME);
	}	

   /* make sure they've setup the conf file properly */
	if ( (strcmp(GetAuth(), "setme") == 0) ) {
	   err_sys("Configuration file still has default values, edit %s and rerun yaunc.", GetConfFilePath());
	}	
		  
	/* if we're set to be a daemon, detach and do all that fun stuff */
	if ((GetDaemonFlag() != 0) && (GetAlreadyDaemon() == 0)) {
		if ( daemon_init() == -1)
			err_sys("daemon_init() failure, exitting");
		
		/* report process starting on syslog */
		err_msg("Starting in daemon mode");
		SetAlreadyDaemon(1);
	}

	/* get system information (type, etc) */
	if ( (error_test = uname(&system_info)) == -1) {
		err_msg("uname() failed, continuing");
	}
	
	/* main processing loop */
	do {
		if ( (uptime = get_uptime(&idle)) == -1)
		   err_sys("get_uptime() failed, exitting");

		snprintf(send_me, MAXLINE, "%s|%d|%1.2f|%1.2f|%s|%s|%s|%s",
			GetAuth(), (int) uptime, load, idle, 
			system_info.sysname, system_info.release, system_info.machine, 
			client);
		   
	#ifdef DEBUG1
		fprintf(stderr, "not sent yet:\n%s\n", send_me);
	#endif

	#ifndef DEBUG1
		/* make the data string and send it along it's merry way */
		if (send_data(send_me) < 0)
			err_ret("%s: send_data() failed, continuing", NAME);
	#endif
	} while ((sleep(GetDelay()) == 0));

	/* never reached */
	exit(0);
}
